@@ -68,6 +68,11 @@
 #define BTN_STYLUS3 0x149
 #endif
 
+/* This value is arbitrary, but low enough values can cause integer division to round
+ * non-zero numbers to zero. See https://github.com/linuxwacom/xf86-input-wacom/pull/222#discussion_r927920625.
+ */
+#define PANSCROLL_INCREMENT 0xffff
+
 /******************************************************************************
  * Forward Declarations
  *****************************************************************************/
@@ -172,6 +177,8 @@ struct _WacomModel
 #define WHEEL_ABS_DN      3
 #define WHEEL2_ABS_UP     4
 #define WHEEL2_ABS_DN     5
+#define WHEEL2_REL_UP     6
+#define WHEEL2_REL_DN     7
 #define STRIP_LEFT_UP     0
 #define STRIP_LEFT_DN     1
 #define STRIP_RIGHT_UP    2
@@ -202,6 +209,7 @@ struct _WacomDeviceState
 	int abswheel;
 	int abswheel2;
 	int relwheel;
+	int relwheel2;
 	int distance;
 	int throttle;
 	int proximity;
@@ -267,13 +275,13 @@ struct _WacomDeviceRec
 	 */
 	int button_default[WCM_MAX_BUTTONS]; /* Default mappings set by ourselves (possibly overridden by xorg.conf) */
 	int strip_default[4];
-	int wheel_default[6];
+	int wheel_default[8];
 	WacomAction key_actions[WCM_MAX_BUTTONS]; /* Action codes to perform when the associated event occurs */
 	WacomAction strip_actions[4];
-	WacomAction wheel_actions[6];
+	WacomAction wheel_actions[8];
 	Atom btn_action_props[WCM_MAX_BUTTONS];   /* Action references so we can update the action codes when a client makes a change */
 	Atom strip_action_props[4];
-	Atom wheel_action_props[6];
+	Atom wheel_action_props[8];
 
 	int nbuttons;           /* number of buttons for this subdevice */
 	int naxes;              /* number of axes */
@@ -302,6 +310,8 @@ struct _WacomDeviceRec
 	WacomTimerPtr serial_timer; /* timer used for serial number property update */
 	WacomTimerPtr tap_timer;   /* timer used for tap timing */
 	WacomTimerPtr touch_timer; /* timer used for touch switch property update */
+
+	ValuatorMask *valuator_mask; /* reusable valuator mask for sending events without reallocation */
 };
 
 #define MAX_SAMPLES	20
@@ -458,6 +468,7 @@ struct _WacomCommonRec
 	int wcmPressureRecalibration; /* Determine if pressure recalibration of
 					 worn pens should be performed */
 	int wcmPanscrollThreshold;	/* distance pen must move to send a panscroll event */
+	int wcmPanscrollIsSmooth;	/* nonzero if smooth panscrolling is enabled */
 
 	int bufpos;                        /* position with buffer */
 	unsigned char buffer[BUFFER_SIZE]; /* data read from device */
